////////////////////////////////////////////////////////////////
// 電卓ガジェット
//   Copyright (C) 2008 - 2012 AAOh inc.
////////////////////////////////////////////////////////////////

/**
 * @fileOverview 電卓ガジェット
 * @author       $Author: fujishiro $
 */

(function () {
/**
 * Main。
 *
 * @constructor
 */
calc.Main = aaoh.kaze.Gadget.extend(
	aaoh.sora.MainEx, function() {
	this.calcValue = '';    // 計算書式
	this.flgCalc   = false; // 計算処理後フラグ
	this.constSign = '';    // 定数演算子
	this.constNum  = '';    // 定数数値
	this.flgConst  = true;  // 定数使用フラグ
	this.stackSign = '';    // スタック演算子
	this.stackNum  = '';    // スタック数値

	this.googleShiftKey = false;
	this.googleCtrlKey  = false;

	this.btnBgImgs   = new Array();
	this.btnBgImgs_u = new Array();
	this.txtCalc     = aaoh.kaze.Gadget.$('txtCalc');
	this.txtCalc_u   = aaoh.kaze.Gadget.$('txtCalc_u');
	this.dispTimer   = new aaoh.kaze.Timer(this);
	this.clipboard   = new aaoh.kaze.Clipboard();
});
	/**
	 * 表示オブジェクトの取得。
	 *
	 * @return 表示オブジェクト
	 */
	calc.Main.prototype.
	getTxtCalc = function() {
		if (aaoh.sora.App.control.flgOnDock) {
			return this.txtCalc;
		}

		return this.txtCalc_u;
	}

	/**
	 * ボタンイメージの取得。
	 *
	 * @return ボタンイメージ
	 */
	calc.Main.prototype.
	getBtnBgImgs = function() {
		if (aaoh.sora.App.control.flgOnDock) {
			return this.btnBgImgs;
		}

		return this.btnBgImgs_u;
	}

	/**
	 * プレフィックスの取得。
	 *
	 * @return プレフィックス
	 */
	calc.Main.prototype.
	getPrefix = function() {
		if (aaoh.sora.App.control.flgOnDock) {
			return '';
		}

		return '_u';
	}

	/**
	 * 計算処理。
	 */
	calc.Main.prototype.
	doCalc = function() {
		if (
			this.calcValue    == ''
			&& this.stackSign == ''
			&& this.stackNum  == ''
		) {
			return;
		}

		// 定数使用判定
		var tmpValue = this.calcValue + this.stackSign + this.stackNum;
		if (this.flgConst) {
			if (this.stackSign != '') {
				tmpValue = tmpValue + this.constNum;
				if (this.stackSign == '-') {
					tmpValue = '(' + tmpValue + ')*-1';
				}

			} else {
				tmpValue = tmpValue + this.constSign + this.constNum;
			}
		}

		var ans = this.calculate(tmpValue);
		if (ans == null) {
			this.doError();
			return;
		}

		if (!this.flgConst) {
			this.constSign = this.stackSign;
			this.constNum  = this.stackNum;
		}

		this.calcValue = '';
		this.stackSign = '';
		this.stackNum  = String(ans);
		this.flgCalc   = true;
		this.flgConst  = true;

		this.showCalc(this.stackNum);
	}

	/**
	 * エラー表示。
	 */
	calc.Main.prototype.
	doError = function() {
		this.calcValue = '';
		this.flgCalc   = false;
		this.stackSign = '';
		this.stackNum  = '';
		this.flgConst  = true;

		// yahoo mac対応
		var msgError = null;
		if (aaoh.kaze.Type.isYahooMac()) {
			msgError = 'Error';

		} else {
			msgError = aaoh.sora.App.control.locale.getString('MSG_ERROR');
		}

		var tmpTxtCalc = this.getTxtCalc();
		aaoh.kaze.Element.setValue(tmpTxtCalc, msgError);
		this.doSoundBeep();
	}

	/**
	 * 値のクリア。
	 */
	calc.Main.prototype.
	doClear = function() {
		this.calcValue = '';
		this.flgCalc   = false;
		this.constSign = '';
		this.constNum  = '';
		this.flgConst  = true;
		this.stackSign = '';
		this.stackNum  = '';

		this.showCalc(this.calcValue);
	}

	/**
	 * 値をひとつ戻す。
	 */
	calc.Main.prototype.
	doBack = function() {
		if (this.stackNum == '') {
			return;
		}

		this.stackNum = this.stackNum.substring(0, this.stackNum.length - 1);
		this.flgCalc  = false;

		this.showCalc(this.stackNum);
	}

	/**
	 * '+/-'を行う。
	 */
	calc.Main.prototype.
	doMinus = function() {
		this.flgConst = false;

		var tmpConst = this.flgConst
		var tmpSign  = this.stackSign;
		var tmpNum   = this.calcValue;
		this.doCalc();

		if (!tmpConst) {
			this.constSign = tmpSign;
			this.constNum  = tmpNum;
		}

		var ans = this.calculate(this.stackNum + '*-1');
		if (ans == null) {
			this.doError();
			return;
		}

		this.calcValue = '';
		this.stackSign = '';
		this.stackNum  = String(ans);
		this.flgCalc   = true;
		this.flgConst  = true;

		this.showCalc(this.stackNum);
	}

	/**
	 * '%'を行う。
	 */
	calc.Main.prototype.
	doPersent = function() {
		var tmpConst = this.flgConst
		var tmpSign  = this.stackSign;
		var tmpNum1  = this.calcValue;
		var tmpNum2  = this.stackNum;

		var tmpValue = null;
		if (tmpSign == '+' || tmpSign == '-') {
			this.stackNum = this.calcValue + tmpSign
				+ this.calcValue + '*' + this.stackNum + '*0.01';
			tmpValue = '';

		} else {
			this.doCalc();
			if (tmpSign == '/') {
				tmpValue = '*100';

			} else {
				tmpValue = '*0.01';
			}
		} // if (tmpSign == '+' || tmpSign == '-')

		if (!tmpConst) {
			this.constSign = tmpSign;

			if (tmpSign == '/') {
				this.constNum = tmpNum2;

			} else {
				this.constNum = tmpNum1;
			}
		}

		var ans = this.calculate(this.stackNum + tmpValue);
		if (ans == null) {
			this.doError();
			return;
		}

		this.calcValue = '';
		this.stackSign = '';
		this.stackNum  = String(ans);
		this.flgCalc   = true;
		this.flgConst  = true;

		this.showCalc(this.stackNum);
	}

	/**
	 * クリップボードへコピーを行う。
	 */
	calc.Main.prototype.
	doCopy = function() {
		if (!this.clipboard.isClipboard()) {
			return;
		}

		// カンマを取除く
		var tmpTxtCalc  = this.getTxtCalc();
		var copyValue = aaoh.kaze.Element.getValue(tmpTxtCalc);
		copyValue = copyValue.replace(/[^0-9\-\.]/g, '');

		// コピー
		this.clipboard.copy(copyValue);
	}

	/**
	 * クリップボードからのペーストを行う。
	 */
	calc.Main.prototype.
	doPaste = function() {
		if (!this.clipboard.isClipboard()) {
			return;
		}

		// ペースト
		var pasteValue = this.clipboard.paste();

		// 数字以外を取除く
		if (pasteValue != null) {
			pasteValue = pasteValue.replace(/[^0-9\+\-\*\/\.]/g, "");
		}
		if (pasteValue == null || pasteValue == '') {
			this.doError();
			return;
		}

		this.stackNum = this.stackNum + pasteValue;
		this.flgConst = false;
		this.doCalc();
	}

	/**
	 * 計算記号の追加。
	 *
	 * @param {String} value 計算記号
	 */
	calc.Main.prototype.
	addSign = function(value) {
		if (
			this.calcValue == ''
			&& this.stackSign == ''
			&& this.stackNum == ''
		) {
			// 最初にマイナス入力対応
			if (value == '-') {
				this.addNumber('-');
				return;

			} else {
				return;
			}
		}

		// 定数設定
		if (this.stackSign != '' && this.stackNum == '') {
			this.flgCalc   = true;
			this.constSign = value;
			this.constNum  = this.calcValue;
			this.flgConst  = true;
			this.stackSign = '';

			if (value == '/') {
				this.calcValue = '1';
			}
			return;
		}

		var ans = this.calculate(
			this.calcValue + this.stackSign + this.stackNum
		);
		if (ans == null) {
			this.doError();
			return;
		}

		if (this.calcValue != '') {
			this.flgConst = false;
		}

		this.calcValue = String(ans);
		this.flgCalc   = false;
		this.stackSign = value;
		this.stackNum  = '';

		this.showCalc(this.calcValue);
	}

	/**
	 * 数字の追加。
	 *
	 * @param {String} value 数字
	 */
	calc.Main.prototype.
	addNumber = function(value) {
		if (this.flgCalc) {
			this.calcValue = '';
			this.stackNum  = value;
			this.flgCalc   = false;

		} else {
			this.stackNum = this.stackNum + value;

			// 有効桁数チェック
			this.stackNum = this.checkMaxLengthString(this.stackNum);
		}

		if (this.stackSign != '') {
			this.flgConst = false;
		}

		this.showCalc(this.stackNum);
	}

	/**
	 * フォーカス設定。
	 */
	calc.Main.prototype.
	setFocus = function() {
		// ボタンが連打できないようにする
		if (aaoh.kaze.Type.isYahoo()) {
			var index = aaoh.kaze.Gadget.$('index');
			aaoh.kaze.Element.setFocus(index);

		} else {
			var tmpTxtCalc = this.getTxtCalc();
			aaoh.kaze.Element.setFocus(tmpTxtCalc);
		}
	}

	/**
	 * 結果表示。
	 *
	 * @param {String} ans 表示数値
	 */
	calc.Main.prototype.
	showCalc = function(ans) {
		if (aaoh.sora.App.model.data.isComma) {
			// カンマをつける
			ans = this.appendComma(ans);
		}

		// google対応
		// yahoo mac対応
		if (aaoh.kaze.Type.isGoogle() || aaoh.kaze.Type.isYahooMac()) {
			var tmpAns = String(ans);
			var len  = aaoh.sora.App.control.MAX_POSITIVE_LENGTH
					+ aaoh.sora.App.control.MAX_NEGATIVE_LENGTH
					- tmpAns.length;

			if (
				aaoh.kaze.Type.isGoogle()
				&& aaoh.sora.App.control.flgOnDock
			) {
				len = len + 1;

			} else if (
				aaoh.kaze.Type.isGoogle()
				&& !aaoh.sora.App.control.flgOnDock
			) {
				len = len + 2;

			} else if (
				aaoh.kaze.Type.isYahooMac()
				&& !aaoh.sora.App.control.flgOnDock
			) {
				len = len + 0;
			}

			for (var cnt = 0; cnt < len; cnt++) {
				tmpAns = ' ' + tmpAns;
			}

			ans = tmpAns;
		}

		var tmpTxtCalc = this.getTxtCalc();
		aaoh.kaze.Element.setValue(tmpTxtCalc, ans);
	}

	/**
	 * 有効桁数チェック。
	 *
	 * @param  {String} value チェック値
	 * @return {String}       有効桁数を満たした値
	 */
	calc.Main.prototype.
	checkMaxLengthString = function(value) {
		var positive = null;
		var negative = null;

		// 有効桁数チェック
		var indexDecimal = value.indexOf('.');
		if (indexDecimal >= 0) {
			positive = value.substring(0, indexDecimal);
			negative = value.substring(indexDecimal);
		} else {
			positive = value;
			negative = '';
		}

		if (positive.length > aaoh.sora.App.control.MAX_POSITIVE_LENGTH) {
			positive = positive.substring(
				0, aaoh.sora.App.control.MAX_POSITIVE_LENGTH
			);
		}
		if (negative.length > aaoh.sora.App.control.MAX_NEGATIVE_LENGTH) {
			negative = negative.substring(
				0, aaoh.sora.App.control.MAX_NEGATIVE_LENGTH
			);
		}

		return positive + negative;
	}

	/**
	 * 有効桁数チェック。
	 *
	 * @param  {Number} num チェック値
	 * @return {Number}     有効桁数を満たした値
	 */
	calc.Main.prototype.
	checkMaxLength = function(num) {
		var ans = this.checkMaxLengthString(String(num));

		return new Number(ans);
	}

	/**
	 * カンマをつける。
	 *
	 * @param  {String} value 元値
	 * @return {String}       カンマを付加した値
	 */
	calc.Main.prototype.
	appendComma = function(value) {
		if (value == null || value.length <= 3) {
			return value;

		} else {
			value = value.toString();
		}
		var sign    = '';
		var decimal = '';

		// 記号を取り除く
		var indexSign = value.indexOf('-');
		if (indexSign >= 0) {
			sign  = value.substring(0, indexSign + 1);
			value = value.substring(indexSign + 1);
		}

		// 小数点以下を取り除く
		var indexDecimal = value.indexOf('.');
		if (indexDecimal >= 0) {
			decimal = value.substring(indexDecimal);
			value   = value.substring(0, indexDecimal);
		}

		// カンマをつける
		var newCnt   = 0;
		var newValue = '';
		for (var cnt = value.length; cnt > 0; cnt--) {
			if (newCnt != 0 && newCnt % 3 == 0) {
				newValue = ',' + newValue;
			}

			newValue = value.charAt(cnt - 1) + newValue;
			newCnt++;
		} // for (var cnt = value.length; cnt >= 0; cnt--)

		return sign + newValue + decimal;
	}

	/**
	 * 数値の計算。。
	 *
	 * @param  {String} value 計算式
	 * @return {Number}       計算結果
	 */
	calc.Main.prototype.
	calculate = function(value) {
		var ans = Number.NaN;

		try {
			// 計算処理
			ans = eval(value);

		} catch(ex) {
			// エラー
			ans = Number.NaN;

		} finally {
			// 有効数値チェック
			var flgAns = isNaN(ans);
			if (
				flgAns
				|| ans == Number.POSITIVE_INFINITY
				|| ans == Number.NEGATIVE_INFINITY
			) {
				ans = null;
			}
		}

		// 小数点補正
		var tmpAnsStr    = String(ans);
		var indexDecimal = tmpAnsStr.indexOf('.');
		if (indexDecimal >= 0) {
			var tmpAns1 = ans * Math.pow(
				10, aaoh.sora.App.control.MAX_NEGATIVE_LENGTH - 1
			);

			var tmpAns2 = Math.round(tmpAns1) * 10;
			ans = tmpAns2 * Math.pow(
				10, aaoh.sora.App.control.MAX_NEGATIVE_LENGTH * -1
			);
		} // if (indexDecimal >= 0)

		// 有効桁数チェック
		if (ans != null) {
			ans = this.checkMaxLength(ans);
		}

		return ans;
	}

	/**
	 * 音を鳴らします。
	 */
	calc.Main.prototype.
	doSoundBeep = function() {
		if (!aaoh.sora.App.control.sound.isBeep()) {
			return;
		}

		aaoh.sora.App.control.sound.beep();
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	calc.Main.prototype.
	setImgInput = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// google対応
		if (aaoh.kaze.Type.isGoogle()) {
			if (key == 17) {
				this.googleCtrlKey = true;

			} else if (key == 16) {
				this.googleShiftKey = true;
			}
		}

		// Altが押されている
		if (event.altKey) {
			return;
		}

		// コントロールが押されている
		if (event.ctrlKey || this.googleCtrlKey) {
			this.setImgInputCtrl(event);
			return;
		}

		// シフトが押されている
		if (event.shiftKey || this.googleShiftKey) {
			this.setImgInputShift(event);
			return;
		}

		switch (key) {
			// '='
			case 13:
				this.setPushBtn('btnEqual');
				break;

			// 'C'
			case 27:
			case 46:
				this.setPushBtn('btnClear');
				break;

			// 'Back'
			case 8:
				this.setPushBtn('btnBack');
				break;

			// '/'
			case 191:
			case 111:
			case 47: // opera対応
				this.setPushBtn('btnDiv');
				break;

			// '*'
			case 106:
			case 42: // opera対応
				this.setPushBtn('btnMulti');
				break;

			// '-'
			case 109:
			case 189:
			case 45: // opera対応
				this.setPushBtn('btnSub');
				break;

			// '+'
			case 107:
			case 43: // opera対応
			case 61: // opera対応(mac opera)
				this.setPushBtn('btnAdd');
				break;

			// テンキー(数字)
			case  96:
			case  97:
			case  98:
			case  99:
			case 100:
			case 101:
			case 102:
			case 103:
			case 104:
			case 105:
				key = key - 48;

			// 数字
			case 48:
			case 49:
			case 50:
			case 51:
			case 52:
			case 53:
			case 54:
			case 55:
			case 56:
			case 57:
				var value = String.fromCharCode(key);
				this.setPushBtn('btn' + value);
				break;

			// '.'
			case 110:
			case 190:
			case 46: // opera対応
			case 78: // opera対応
				this.setPushBtn('btnDott');
				break;

			default:
				break;
		} // switch (key)
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	calc.Main.prototype.
	setImgInputCtrl = function(event) {
		var key = event.keyCode;

		switch (key) {
			// 'Ctrl + C'
			case 67:
			// 'Ctrl + Ins'
			case 45:
				this.setPushBtn('btnCopy');
				break;

			// 'Ctrl + V'
			case 86:
				this.setPushBtn('btnPaste');
				break;

			default:
				break;
		} // switch (key)
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	calc.Main.prototype.
	setImgInputShift = function(event) {
		var key = event.keyCode;

		switch (key) {
			// '='
			case 189:
			case 109:
				this.setPushBtn('btnEqual');
				break;

			// '*'
			case 186:
			case 57:
			case 59:
			//case 58: // opera対応
				this.setPushBtn('btnMulti');
				break;

			// '+'
			case 187:
			case 107:
			//case 59: // opera対応
				this.setPushBtn('btnAdd');
				break;

			// '%'
			case 53:
				this.setPushBtn('btnPersent');
				break;

			// 'Shift + Ins'
			case 45:
				// opera対応
				if (aaoh.kaze.Type.isOpera()) {
					this.setPushBtn('btnEqual');

				} else {
					this.setPushBtn('btnPaste');
				}
				break;

			default:
				break;
		} // switch (key)
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	calc.Main.prototype.
	doInput = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// Altが押されている
		if (event.altKey) {
			return;
		}

		// コントロールが押されている
		if (event.ctrlKey || this.googleCtrlKey) {
			this.doInputCtrl(event);

			// google対応
			if (aaoh.kaze.Type.isGoogle() && key == 17) {
				this.googleCtrlKey = false;
			}
			return;
		}

		// シフトが押されている
		if (event.shiftKey || this.googleShiftKey) {
			this.doInputShift(event);

			// google対応
			if (aaoh.kaze.Type.isGoogle() && key == 16) {
				this.googleShiftKey = false;
			}
			return;
		}

		switch (key) {
			// '='
			case 13:
				this.doCalc();
				this.clearPushBtn('btnEqual');
				break;

			// 'C'
			case 27:
			case 46:
				this.doClear();
				this.clearPushBtn('btnClear');
				break;

			// 'Back'
			case 8:
				this.doBack();
				this.clearPushBtn('btnBack');
				break;

			// '/'
			case 191:
			case 111:
			case 47: // opera対応
				this.addSign('/');
				this.clearPushBtn('btnDiv');
				break;

			// '*'
			case 106:
			case 42: // opera対応
				this.addSign('*');
				this.clearPushBtn('btnMulti');
				break;

			// '-'
			case 109:
			case 189:
			case 45: // opera対応
				this.addSign('-');
				this.clearPushBtn('btnSub');
				//break;
			// '='
			//case 189:
			case 45: // opera対応
				this.clearPushBtn('btnEqual');
				break;

			// '+'
			case 107:
			case 43: // opera対応
			case 61: // opera対応(mac opera)
				this.addSign('+');
				this.clearPushBtn('btnAdd');
				break;

			// テンキー(数字)
			case  96:
			case  97:
			case  98:
			case  99:
			case 100:
			case 101:
			case 102:
			case 103:
			case 104:
			case 105:
				key = key - 48;

			// 数字
			case 48:
			case 49:
			case 50:
			case 51:
			case 52:
			case 53:
			case 54:
			case 55:
			case 56:
			case 57:
				var value = String.fromCharCode(key);
				this.addNumber(value);
				this.clearPushBtn('btn' + value);
				if (key == 53) {
					this.clearPushBtn('btnPersent');
				}
				//break;
			// '%'
			//case 53:
				this.clearPushBtn('btnPersent');
				break;

			// '.'
			case 110:
			case 190:
			case 46: // opera対応
			case 78: // opera対応
				this.addNumber('.');
				this.clearPushBtn('btnDott');
				break;

			// Ctlだけ離されたときの対応
			// 'Ctrl + C'
			case 67:
			// 'Ctrl + Ins'
			// 'Shift + Ins'
			case 45:
				this.clearPushBtn('btnCopy');
				this.clearPushBtn('btnPaste');
				break;

			// 'Ctrl + V'
			case 86:
				this.clearPushBtn('btnPaste');
				break;

			// '*'
			case 186:
			//case 58: // opera対応
				this.clearPushBtn('btnMulti');
				break;

			// '+'
			case 187:
			//case 59: // opera対応
				this.clearPushBtn('btnAdd');
				break;

			default:
				break;
		} // switch (key)
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	calc.Main.prototype.
	doInputCtrl = function(event) {
		var key = event.keyCode;

		switch (key) {
			// 'Ctrl + C'
			case 67:
			// 'Ctrl + Ins'
			case 45:
				this.doCopy();
				this.clearPushBtn('btnCopy');
				break;

			// 'Ctrl + V'
			case 86:
				this.doPaste();
				this.clearPushBtn('btnPaste');
				break;

			default:
				break;
		} // switch (key)
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	calc.Main.prototype.
	doInputShift = function(event) {
		var key = event.keyCode;

		switch (key) {
			// '='
			case 189:
			case 109:
				this.doCalc();
				this.clearPushBtn('btnEqual');
				break;

			// '*'
			case 186:
			case 59:
			//case 58: // opera対応
				this.addSign('*');
				this.clearPushBtn('btnMulti');
				break;

			// '+'
			case 187:
			case 107:
			//case 59: // opera対応
				this.addSign('+');
				this.clearPushBtn('btnAdd');
				break;

			// '%'
			case 53:
				this.doPersent();
				this.clearPushBtn('btnPersent');
				break;

			// 'Shift + Ins'
			case 45:
				// opera対応
				if (aaoh.kaze.Type.isOpera()) {
					this.doCalc();
					this.clearPushBtn('btnEqual');

				} else {
					this.doPaste();
					this.clearPushBtn('btnPaste');
				}
				break;

			default:
				break;
		} // switch (key)
	}

	/**
	 * 押下されたときのボタン設定。
	 *
	 * @param {String} target 対象ID
	 */
	calc.Main.prototype.
	setPushBtn = function(target) {
		var targetElement = target + this.getPrefix();
		var element       = aaoh.kaze.Gadget.$(targetElement);
		if (element == null) {
			return;
		}

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo() && !aaoh.sora.App.control.flgOnDock) {
			// 描画が遅いので何もしない
			return;
		}

		var tmpBtnBgImgs = this.getBtnBgImgs();
		aaoh.kaze.Element.setBackgroundImage(
			element, tmpBtnBgImgs[target][2]
		);
	}

	/**
	 * 離されたときのボタン設定。
	 *
	 * @param {String} target 対象ID
	 */
	calc.Main.prototype.
	clearPushBtn = function(target) {
		var targetElement = target + this.getPrefix();
		var element       = aaoh.kaze.Gadget.$(targetElement);
		if (element == null) {
			return;
		}

		// yahoo対応
		if (aaoh.kaze.Type.isYahoo() && !aaoh.sora.App.control.flgOnDock) {
			// 描画が遅いので何もしない
			return;
		}

		var tmpBtnBgImgs = this.getBtnBgImgs();
		aaoh.kaze.Element.setBackgroundImage(
			element,
			tmpBtnBgImgs[target][0],
			tmpBtnBgImgs[target][1],
			tmpBtnBgImgs[target][2]
		);
	}

	/**
	 * 表示データの初期化。
	 */
	calc.Main.prototype.
	initData = function() {
		this.doClear();

		var flgOnDock = aaoh.sora.App.control.flgOnDock;
		var type      = aaoh.sora.App.model.data.type;

		this.initToolbarData(type);

		if (flgOnDock) {
			var main    = aaoh.kaze.Gadget.$('onDock');
			var srcMain = null;
			if (aaoh.kaze.Type.isSidebar()) {
				srcMain = 'lib/aaoh.sora.t.png';

			} else {
				srcMain = 'images/calc' + type + '-base.png';
			}
			// IE6では入れ子透過PNG対応しない
			aaoh.kaze.Element.setBackgroundImage(main, srcMain, false);

		} else {
			var main    = aaoh.kaze.Gadget.$('unDock');
			var srcMain = null;
			if (aaoh.kaze.Type.isSidebar()) {
				srcMain = 'lib/aaoh.sora.t.png';

			} else {
				srcMain = 'images/calc' + type + '-undock.png';
			}
			// IE6では入れ子透過PNG対応しない
			aaoh.kaze.Element.setBackgroundImage(main, srcMain, false);
		} // if (flgOnDock)

		// 透過PNG対応
		if (aaoh.kaze.Type.isSidebar()) {
			var sidebarImgBg = aaoh.kaze.Gadget.$('sidebarImgBg');

			var srcSidebarImgBg = null;
			if (flgOnDock) {
				srcSidebarImgBg = 'images/calc' + type + '-base_sidebar.png';
				sidebarImgBg.style.width
				= aaoh.sora.App.control.WINDOW_ONDOCK_WIDTH + 'px';
				sidebarImgBg.style.height
					= aaoh.sora.App.control.WINDOW_ONDOCK_HEIGHT + 'px';

			} else {
				srcSidebarImgBg = 'images/calc' + type + '-undock_sidebar.png';
				sidebarImgBg.style.width
				= aaoh.sora.App.control.WINDOW_UNDOCK_WIDTH + 'px';
				sidebarImgBg.style.height
					= aaoh.sora.App.control.WINDOW_UNDOCK_HEIGHT + 'px';
			}

			aaoh.kaze.Element.setImage(sidebarImgBg, srcSidebarImgBg);
		}

		var tipCopy  = aaoh.sora.App.control.locale.getString('TIP_COPY');
		var tipPaste = aaoh.sora.App.control.locale.getString('TIP_PASTE');
		if (flgOnDock) {
			var btnCopy  = aaoh.kaze.Gadget.$('btnCopy');
			var btnPaste = aaoh.kaze.Gadget.$('btnPaste');

			if (this.clipboard.isClipboard()) {
				aaoh.kaze.Element.setTooltip(btnCopy,  tipCopy);
				aaoh.kaze.Element.setTooltip(btnPaste, tipPaste);

			} else {
				// コピー&ペーストできないのは非表示にする
				aaoh.kaze.Element.setVisible(btnCopy,  false);
				aaoh.kaze.Element.setVisible(btnPaste, false);
			}

			this.initOnDockColor(type);
			this.initOnDockData(type);

		} else {
			var btnCopy_u  = aaoh.kaze.Gadget.$('btnCopy_u');
			var btnPaste_u = aaoh.kaze.Gadget.$('btnPaste_u');

			if (this.clipboard.isClipboard()) {
				aaoh.kaze.Element.setTooltip(btnCopy_u,  tipCopy);
				aaoh.kaze.Element.setTooltip(btnPaste_u, tipPaste);

			} else {
				// コピー&ペーストできないのは非表示にする
				aaoh.kaze.Element.setVisible(btnCopy_u,  false);
				aaoh.kaze.Element.setVisible(btnPaste_u, false);
			}

			this.initUnDockColor(type);
			this.initUnDockData(type);
		}

		this.dispTimer.setTimeout(function() {
			aaoh.sora.App.main.setFocus();
			aaoh.sora.App.main.doClear();
		}, 200);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	calc.Main.prototype.
	initToolbarData = function(type) {
		var btnMax    = aaoh.kaze.Gadget.$('btnMax');
		var btnOption = aaoh.kaze.Gadget.$('btnOption');
		var btnClose  = aaoh.kaze.Gadget.$('btnClose');
		if (btnMax == null || btnOption == null || btnClose == null) {
			return;
		}

		var srcBtnMaxUp      = null;
		var srcBtnMaxOver    = null;
		var srcBtnMaxDown    = null;
		var srcBtnOptionUp   = null;
		var srcBtnOptionOver = null;
		var srcBtnOptionDown = null;
		var srcBtnCloseUp    = null;
		var srcBtnCloseOver  = null;
		var srcBtnCloseDown  = null;
		if (!aaoh.kaze.Type.isGoogle() && !aaoh.kaze.Type.isIE()) {
			srcBtnMaxUp    = 'images/calc' + type + '-max.png';
			srcBtnOptionUp = 'images/calc' + type + '-option.png';
			srcBtnCloseUp  = 'images/calc' + type + '-close.png';

		} else {
			srcBtnMaxUp    = 'sub-images/calc' + type + '-max_up.png';
			srcBtnOptionUp = 'sub-images/calc' + type + '-option_up.png';
			srcBtnCloseUp  = 'sub-images/calc' + type + '-close_up.png';
		}
		srcBtnMaxOver    = 'sub-images/calc' + type + '-max_over.png';
		srcBtnMaxDown    = 'sub-images/calc' + type + '-max_down.png';
		srcBtnOptionOver = 'sub-images/calc' + type + '-option_over.png';
		srcBtnOptionDown = 'sub-images/calc' + type + '-option_down.png';
		srcBtnCloseOver  = 'sub-images/calc' + type + '-close_over.png';
		srcBtnCloseDown  = 'sub-images/calc' + type + '-close_down.png';

		aaoh.kaze.Element.setBackgroundImage(
			btnMax, srcBtnMaxUp, srcBtnMaxOver, srcBtnMaxDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnOption, srcBtnOptionUp, srcBtnOptionOver, srcBtnOptionDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnClose, srcBtnCloseUp, srcBtnCloseOver, srcBtnCloseDown
		);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	calc.Main.prototype.
	initOnDockColor = function(type) {
		var fgColor = null;
		var bgColor = null;
		switch (type) {
			default:
			case '1':
				fgColor = '#000000';
				bgColor = '#ffffff';
				break;

			case '2':
				fgColor = '#ffffff';
				bgColor = '#000000';
				break;

			case '3':
				fgColor = '#ffffff';
				bgColor = '#ff0000';
				break;

			case '4':
				fgColor = '#ffffff';
				bgColor = '#000000';
				break;

			case '5':
				fgColor = '#ffffff';
				bgColor = '#ff0000';
				break;

			case '6':
				fgColor = '#ffffff';
				bgColor = '#000000';
				break;
		}

		aaoh.kaze.Element.setForeground(this.txtCalc, fgColor);
		aaoh.kaze.Element.setBackground(this.txtCalc, bgColor);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	calc.Main.prototype.
	initUnDockColor = function(type) {
		var btnClear   = aaoh.kaze.Gadget.$('btnClear_u');
		var btnAdd     = aaoh.kaze.Gadget.$('btnAdd_u');
		var btnBack    = aaoh.kaze.Gadget.$('btnBack_u');
		var btnMinus   = aaoh.kaze.Gadget.$('btnMinus_u');
		var btnPersent = aaoh.kaze.Gadget.$('btnPersent_u');
		var btnDiv     = aaoh.kaze.Gadget.$('btnDiv_u');
		var btnMulti   = aaoh.kaze.Gadget.$('btnMulti_u');
		var btnSub     = aaoh.kaze.Gadget.$('btnSub_u');
		var btnDott    = aaoh.kaze.Gadget.$('btnDott_u');
		var btnEqual   = aaoh.kaze.Gadget.$('btnEqual_u');
		var btn0       = aaoh.kaze.Gadget.$('btn0_u');
		var btn1       = aaoh.kaze.Gadget.$('btn1_u');
		var btn2       = aaoh.kaze.Gadget.$('btn2_u');
		var btn3       = aaoh.kaze.Gadget.$('btn3_u');
		var btn4       = aaoh.kaze.Gadget.$('btn4_u');
		var btn5       = aaoh.kaze.Gadget.$('btn5_u');
		var btn6       = aaoh.kaze.Gadget.$('btn6_u');
		var btn7       = aaoh.kaze.Gadget.$('btn7_u');
		var btn8       = aaoh.kaze.Gadget.$('btn8_u');
		var btn9       = aaoh.kaze.Gadget.$('btn9_u');

		var fgColor = null;
		var bgColor = null;
		switch (type) {
			default:
			case '1':
				fgColor = '#000000';
				bgColor = '#ffffff';
				break;

			case '2':
				fgColor = '#ffffff';
				bgColor = '#000000';
				break;

			case '3':
				fgColor = '#ffffff';
				bgColor = '#ff0000';
				break;

			case '4':
				fgColor = '#ffffff';
				bgColor = '#000000';
				break;

			case '5':
				fgColor = '#ffffff';
				bgColor = '#ff0000';
				break;

			case '6':
				fgColor = '#ffffff';
				bgColor = '#000000';
				break;
		}

		aaoh.kaze.Element.setForeground(this.txtCalc_u, fgColor);
		aaoh.kaze.Element.setBackground(this.txtCalc_u, bgColor);

		aaoh.kaze.Element.setForeground(btnClear,   fgColor);
		aaoh.kaze.Element.setForeground(btnAdd,     fgColor);
		aaoh.kaze.Element.setForeground(btnBack,    fgColor);
		aaoh.kaze.Element.setForeground(btnMinus,   fgColor);
		aaoh.kaze.Element.setForeground(btnPersent, fgColor);
		aaoh.kaze.Element.setForeground(btnDiv,     fgColor);
		aaoh.kaze.Element.setForeground(btnMulti,   fgColor);
		aaoh.kaze.Element.setForeground(btnSub,     fgColor);
		aaoh.kaze.Element.setForeground(btnDott,    fgColor);
		aaoh.kaze.Element.setForeground(btnEqual,   fgColor);
		aaoh.kaze.Element.setForeground(btn0,       fgColor);
		aaoh.kaze.Element.setForeground(btn1,       fgColor);
		aaoh.kaze.Element.setForeground(btn2,       fgColor);
		aaoh.kaze.Element.setForeground(btn3,       fgColor);
		aaoh.kaze.Element.setForeground(btn4,       fgColor);
		aaoh.kaze.Element.setForeground(btn5,       fgColor);
		aaoh.kaze.Element.setForeground(btn6,       fgColor);
		aaoh.kaze.Element.setForeground(btn7,       fgColor);
		aaoh.kaze.Element.setForeground(btn8,       fgColor);
		aaoh.kaze.Element.setForeground(btn9,       fgColor);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	calc.Main.prototype.
	initOnDockData = function(type) {
		var btnCopy    = aaoh.kaze.Gadget.$('btnCopy');
		var btnPaste   = aaoh.kaze.Gadget.$('btnPaste');
		var btnClear   = aaoh.kaze.Gadget.$('btnClear');
		var btnAdd     = aaoh.kaze.Gadget.$('btnAdd');
		var btnBack    = aaoh.kaze.Gadget.$('btnBack');
		var btnMinus   = aaoh.kaze.Gadget.$('btnMinus');
		var btnPersent = aaoh.kaze.Gadget.$('btnPersent');
		var btnDiv     = aaoh.kaze.Gadget.$('btnDiv');
		var btnMulti   = aaoh.kaze.Gadget.$('btnMulti');
		var btnSub     = aaoh.kaze.Gadget.$('btnSub');
		var btnDott    = aaoh.kaze.Gadget.$('btnDott');
		var btnEqual   = aaoh.kaze.Gadget.$('btnEqual');
		var btn0       = aaoh.kaze.Gadget.$('btn0');
		var btn1       = aaoh.kaze.Gadget.$('btn1');
		var btn2       = aaoh.kaze.Gadget.$('btn2');
		var btn3       = aaoh.kaze.Gadget.$('btn3');
		var btn4       = aaoh.kaze.Gadget.$('btn4');
		var btn5       = aaoh.kaze.Gadget.$('btn5');
		var btn6       = aaoh.kaze.Gadget.$('btn6');
		var btn7       = aaoh.kaze.Gadget.$('btn7');
		var btn8       = aaoh.kaze.Gadget.$('btn8');
		var btn9       = aaoh.kaze.Gadget.$('btn9');

		var srcBtnCopyUp      = null;
		var srcBtnCopyOver    = null;
		var srcBtnCopyDown    = null;
		var srcBtnPasteUp     = null;
		var srcBtnPasteOver   = null;
		var srcBtnPasteDown   = null;
		var srcBtnClearUp     = null;
		var srcBtnClearOver   = null;
		var srcBtnClearDown   = null;
		var srcBtnAddUp       = null;
		var srcBtnAddOver     = null;
		var srcBtnAddDown     = null;
		var srcBtnBackUp      = null;
		var srcBtnBackOver    = null;
		var srcBtnBackDown    = null;
		var srcBtnMinusUp     = null;
		var srcBtnMinusOver   = null;
		var srcBtnMinusDown   = null;
		var srcBtnPersentUp   = null;
		var srcBtnPersentOver = null;
		var srcBtnPersentDown = null;
		var srcBtnDivUp       = null;
		var srcBtnDivOver     = null;
		var srcBtnDivDown     = null;
		var srcBtnMultiUp     = null;
		var srcBtnMultiOver   = null;
		var srcBtnMultiDown   = null;
		var srcBtnSubUp       = null;
		var srcBtnSubOver     = null;
		var srcBtnSubDown     = null;
		var srcBtnDottUp      = null;
		var srcBtnDottOver    = null;
		var srcBtnDottDown    = null;
		var srcBtnEqualUp     = null;
		var srcBtnEqualOver   = null;
		var srcBtnEqualDown   = null;
		var srcBtn0Up         = null;
		var srcBtn0Over       = null;
		var srcBtn0Down       = null;
		var srcBtn1Up         = null;
		var srcBtn1Over       = null;
		var srcBtn1Down       = null;
		var srcBtn2Up         = null;
		var srcBtn2Over       = null;
		var srcBtn2Down       = null;
		var srcBtn3Up         = null;
		var srcBtn3Over       = null;
		var srcBtn3Down       = null;
		var srcBtn4Up         = null;
		var srcBtn4Over       = null;
		var srcBtn4Down       = null;
		var srcBtn5Up         = null;
		var srcBtn5Over       = null;
		var srcBtn5Down       = null;
		var srcBtn6Up         = null;
		var srcBtn6Over       = null;
		var srcBtn6Down       = null;
		var srcBtn7Up         = null;
		var srcBtn7Over       = null;
		var srcBtn7Down       = null;
		var srcBtn8Up         = null;
		var srcBtn8Over       = null;
		var srcBtn8Down       = null;
		var srcBtn9Up         = null;
		var srcBtn9Over       = null;
		var srcBtn9Down       = null;
		if (!aaoh.kaze.Type.isGoogle() && !aaoh.kaze.Type.isIE()) {
			srcBtnCopyUp    = 'images/calc' + type + '-copy.png';
			srcBtnPasteUp   = 'images/calc' + type + '-paste.png';
			srcBtnClearUp   = 'images/calc' + type + '-clear.png';
			srcBtnAddUp     = 'images/calc' + type + '-add.png';
			srcBtnBackUp    = 'images/calc' + type + '-back.png';
			srcBtnMinusUp   = 'images/calc' + type + '-minus.png';
			srcBtnPersentUp = 'images/calc' + type + '-persent.png';
			srcBtnDivUp     = 'images/calc' + type + '-div.png';
			srcBtnMultiUp   = 'images/calc' + type + '-multi.png';
			srcBtnSubUp     = 'images/calc' + type + '-sub.png';
			srcBtnDottUp    = 'images/calc' + type + '-dott.png';
			srcBtnEqualUp   = 'images/calc' + type + '-equal.png';
			srcBtn0Up       = 'images/calc' + type + '-0.png';
			srcBtn1Up       = 'images/calc' + type + '-1.png';
			srcBtn2Up       = 'images/calc' + type + '-2.png';
			srcBtn3Up       = 'images/calc' + type + '-3.png';
			srcBtn4Up       = 'images/calc' + type + '-4.png';
			srcBtn5Up       = 'images/calc' + type + '-5.png';
			srcBtn6Up       = 'images/calc' + type + '-6.png';
			srcBtn7Up       = 'images/calc' + type + '-7.png';
			srcBtn8Up       = 'images/calc' + type + '-8.png';
			srcBtn9Up       = 'images/calc' + type + '-9.png';

		} else {
			srcBtnCopyUp    = 'sub-images/calc' + type + '-copy_up.png';
			srcBtnPasteUp   = 'sub-images/calc' + type + '-paste_up.png';
			srcBtnClearUp   = 'sub-images/calc' + type + '-clear_up.png';
			srcBtnAddUp     = 'sub-images/calc' + type + '-add_up.png';
			srcBtnBackUp    = 'sub-images/calc' + type + '-back_up.png';
			srcBtnMinusUp   = 'sub-images/calc' + type + '-minus_up.png';
			srcBtnPersentUp = 'sub-images/calc' + type + '-persent_up.png';
			srcBtnDivUp     = 'sub-images/calc' + type + '-div_up.png';
			srcBtnMultiUp   = 'sub-images/calc' + type + '-multi_up.png';
			srcBtnSubUp     = 'sub-images/calc' + type + '-sub_up.png';
			srcBtnDottUp    = 'sub-images/calc' + type + '-dott_up.png';
			srcBtnEqualUp   = 'sub-images/calc' + type + '-equal_up.png';
			srcBtn0Up       = 'sub-images/calc' + type + '-0_up.png';
			srcBtn1Up       = 'sub-images/calc' + type + '-1_up.png';
			srcBtn2Up       = 'sub-images/calc' + type + '-2_up.png';
			srcBtn3Up       = 'sub-images/calc' + type + '-3_up.png';
			srcBtn4Up       = 'sub-images/calc' + type + '-4_up.png';
			srcBtn5Up       = 'sub-images/calc' + type + '-5_up.png';
			srcBtn6Up       = 'sub-images/calc' + type + '-6_up.png';
			srcBtn7Up       = 'sub-images/calc' + type + '-7_up.png';
			srcBtn8Up       = 'sub-images/calc' + type + '-8_up.png';
			srcBtn9Up       = 'sub-images/calc' + type + '-9_up.png';
		}
		srcBtnCopyOver    = 'sub-images/calc' + type + '-copy_over.png';
		srcBtnCopyDown    = 'sub-images/calc' + type + '-copy_down.png';
		srcBtnPasteOver   = 'sub-images/calc' + type + '-paste_over.png';
		srcBtnPasteDown   = 'sub-images/calc' + type + '-paste_down.png';
		srcBtnClearOver   = 'sub-images/calc' + type + '-clear_over.png';
		srcBtnClearDown   = 'sub-images/calc' + type + '-clear_down.png';
		srcBtnAddOver     = 'sub-images/calc' + type + '-add_over.png';
		srcBtnAddDown     = 'sub-images/calc' + type + '-add_down.png';
		srcBtnBackOver    = 'sub-images/calc' + type + '-back_over.png';
		srcBtnBackDown    = 'sub-images/calc' + type + '-back_down.png';
		srcBtnMinusOver   = 'sub-images/calc' + type + '-minus_over.png';
		srcBtnMinusDown   = 'sub-images/calc' + type + '-minus_down.png';
		srcBtnPersentOver = 'sub-images/calc' + type + '-persent_over.png';
		srcBtnPersentDown = 'sub-images/calc' + type + '-persent_down.png';
		srcBtnDivOver     = 'sub-images/calc' + type + '-div_over.png';
		srcBtnDivDown     = 'sub-images/calc' + type + '-div_down.png';
		srcBtnMultiOver   = 'sub-images/calc' + type + '-multi_over.png';
		srcBtnMultiDown   = 'sub-images/calc' + type + '-multi_down.png';
		srcBtnSubOver     = 'sub-images/calc' + type + '-sub_over.png';
		srcBtnSubDown     = 'sub-images/calc' + type + '-sub_down.png';
		srcBtnDottOver    = 'sub-images/calc' + type + '-dott_over.png';
		srcBtnDottDown    = 'sub-images/calc' + type + '-dott_down.png';
		srcBtnEqualOver   = 'sub-images/calc' + type + '-equal_over.png';
		srcBtnEqualDown   = 'sub-images/calc' + type + '-equal_down.png';
		srcBtn0Over       = 'sub-images/calc' + type + '-0_over.png';
		srcBtn0Down       = 'sub-images/calc' + type + '-0_down.png';
		srcBtn1Over       = 'sub-images/calc' + type + '-1_over.png';
		srcBtn1Down       = 'sub-images/calc' + type + '-1_down.png';
		srcBtn2Over       = 'sub-images/calc' + type + '-2_over.png';
		srcBtn2Down       = 'sub-images/calc' + type + '-2_down.png';
		srcBtn3Over       = 'sub-images/calc' + type + '-3_over.png';
		srcBtn3Down       = 'sub-images/calc' + type + '-3_down.png';
		srcBtn4Over       = 'sub-images/calc' + type + '-4_over.png';
		srcBtn4Down       = 'sub-images/calc' + type + '-4_down.png';
		srcBtn5Over       = 'sub-images/calc' + type + '-5_over.png';
		srcBtn5Down       = 'sub-images/calc' + type + '-5_down.png';
		srcBtn6Over       = 'sub-images/calc' + type + '-6_over.png';
		srcBtn6Down       = 'sub-images/calc' + type + '-6_down.png';
		srcBtn7Over       = 'sub-images/calc' + type + '-7_over.png';
		srcBtn7Down       = 'sub-images/calc' + type + '-7_down.png';
		srcBtn8Over       = 'sub-images/calc' + type + '-8_over.png';
		srcBtn8Down       = 'sub-images/calc' + type + '-8_down.png';
		srcBtn9Over       = 'sub-images/calc' + type + '-9_over.png';
		srcBtn9Down       = 'sub-images/calc' + type + '-9_down.png';

		aaoh.kaze.Element.setBackgroundImage(
			btnCopy, srcBtnCopyUp, srcBtnCopyOver, srcBtnCopyDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnPaste, srcBtnPasteUp, srcBtnPasteOver, srcBtnPasteDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnClear, srcBtnClearUp, srcBtnClearOver, srcBtnClearDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnAdd, srcBtnAddUp, srcBtnAddOver, srcBtnAddDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnBack, srcBtnBackUp, srcBtnBackOver, srcBtnBackDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnMinus, srcBtnMinusUp, srcBtnMinusOver, srcBtnMinusDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnPersent, srcBtnPersentUp, srcBtnPersentOver, srcBtnPersentDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnDiv, srcBtnDivUp, srcBtnDivOver, srcBtnDivDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnMulti, srcBtnMultiUp, srcBtnMultiOver, srcBtnMultiDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnSub, srcBtnSubUp, srcBtnSubOver, srcBtnSubDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnDott, srcBtnDottUp, srcBtnDottOver, srcBtnDottDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnEqual, srcBtnEqualUp, srcBtnEqualOver, srcBtnEqualDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn0, srcBtn0Up, srcBtn0Over, srcBtn0Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn1, srcBtn1Up, srcBtn1Over, srcBtn1Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn2, srcBtn2Up, srcBtn2Over, srcBtn2Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn3, srcBtn3Up, srcBtn3Over, srcBtn3Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn4, srcBtn4Up, srcBtn4Over, srcBtn4Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn5, srcBtn5Up, srcBtn5Over, srcBtn5Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn6, srcBtn6Up, srcBtn6Over, srcBtn6Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn7, srcBtn7Up, srcBtn7Over, srcBtn7Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn8, srcBtn8Up, srcBtn8Over, srcBtn8Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn9, srcBtn9Up, srcBtn9Over, srcBtn9Down
		);

		// イメージの保存
		this.btnBgImgs['btnCopy'] = new Array(
			srcBtnCopyUp, srcBtnCopyOver, srcBtnCopyDown
		);
		this.btnBgImgs['btnPaste'] = new Array(
			srcBtnPasteUp, srcBtnPasteOver, srcBtnPasteDown
		);
		this.btnBgImgs['btnClear'] = new Array(
			srcBtnClearUp, srcBtnClearOver, srcBtnClearDown
		);
		this.btnBgImgs['btnAdd'] = new Array(
			srcBtnAddUp, srcBtnAddOver, srcBtnAddDown
		);
		this.btnBgImgs['btnBack'] = new Array(
			srcBtnBackUp, srcBtnBackOver, srcBtnBackDown
		);
		this.btnBgImgs['btnMinus'] = new Array(
			srcBtnMinusUp, srcBtnMinusOver, srcBtnMinusDown
		);
		this.btnBgImgs['btnPersent'] = new Array(
			srcBtnPersentUp, srcBtnPersentOver, srcBtnPersentDown
		);
		this.btnBgImgs['btnDiv'] = new Array(
			srcBtnDivUp, srcBtnDivOver, srcBtnDivDown
		);
		this.btnBgImgs['btnMulti'] = new Array(
			srcBtnMultiUp, srcBtnMultiOver, srcBtnMultiDown
		);
		this.btnBgImgs['btnSub'] = new Array(
			srcBtnSubUp, srcBtnSubOver, srcBtnSubDown
		);
		this.btnBgImgs['btnDott'] = new Array(
			srcBtnDottUp, srcBtnDottOver, srcBtnDottDown
		);
		this.btnBgImgs['btnEqual'] = new Array(
			srcBtnEqualUp, srcBtnEqualOver, srcBtnEqualDown
		);
		this.btnBgImgs['btn0'] = new Array(
			srcBtn0Up, srcBtn0Over, srcBtn0Down
		);
		this.btnBgImgs['btn1'] = new Array(
			srcBtn1Up, srcBtn1Over, srcBtn1Down
		);
		this.btnBgImgs['btn2'] = new Array(
			srcBtn2Up, srcBtn2Over, srcBtn2Down
		);
		this.btnBgImgs['btn3'] = new Array(
			srcBtn3Up, srcBtn3Over, srcBtn3Down
		);
		this.btnBgImgs['btn4'] = new Array(
			srcBtn4Up, srcBtn4Over, srcBtn4Down
		);
		this.btnBgImgs['btn5'] = new Array(
			srcBtn5Up, srcBtn5Over, srcBtn5Down
		);
		this.btnBgImgs['btn6'] = new Array(
			srcBtn6Up, srcBtn6Over, srcBtn6Down
		);
		this.btnBgImgs['btn7'] = new Array(
			srcBtn7Up, srcBtn7Over, srcBtn7Down
		);
		this.btnBgImgs['btn8'] = new Array(
			srcBtn8Up, srcBtn8Over, srcBtn8Down
		);
		this.btnBgImgs['btn9'] = new Array(
			srcBtn9Up, srcBtn9Over, srcBtn9Down
		);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	calc.Main.prototype.
	initUnDockData = function(type) {
		var btnCopy    = aaoh.kaze.Gadget.$('btnCopy_u');
		var btnPaste   = aaoh.kaze.Gadget.$('btnPaste_u');
		var btnClear   = aaoh.kaze.Gadget.$('btnClear_u');
		var btnAdd     = aaoh.kaze.Gadget.$('btnAdd_u');
		var btnBack    = aaoh.kaze.Gadget.$('btnBack_u');
		var btnMinus   = aaoh.kaze.Gadget.$('btnMinus_u');
		var btnPersent = aaoh.kaze.Gadget.$('btnPersent_u');
		var btnDiv     = aaoh.kaze.Gadget.$('btnDiv_u');
		var btnMulti   = aaoh.kaze.Gadget.$('btnMulti_u');
		var btnSub     = aaoh.kaze.Gadget.$('btnSub_u');
		var btnDott    = aaoh.kaze.Gadget.$('btnDott_u');
		var btnEqual   = aaoh.kaze.Gadget.$('btnEqual_u');
		var btn0       = aaoh.kaze.Gadget.$('btn0_u');
		var btn1       = aaoh.kaze.Gadget.$('btn1_u');
		var btn2       = aaoh.kaze.Gadget.$('btn2_u');
		var btn3       = aaoh.kaze.Gadget.$('btn3_u');
		var btn4       = aaoh.kaze.Gadget.$('btn4_u');
		var btn5       = aaoh.kaze.Gadget.$('btn5_u');
		var btn6       = aaoh.kaze.Gadget.$('btn6_u');
		var btn7       = aaoh.kaze.Gadget.$('btn7_u');
		var btn8       = aaoh.kaze.Gadget.$('btn8_u');
		var btn9       = aaoh.kaze.Gadget.$('btn9_u');

		var srcBtnCopyUp      = null;
		var srcBtnCopyOver    = null;
		var srcBtnCopyDown    = null;
		var srcBtnPasteUp     = null;
		var srcBtnPasteOver   = null;
		var srcBtnPasteDown   = null;
		var srcBtnClearUp     = null;
		var srcBtnClearOver   = null;
		var srcBtnClearDown   = null;
		var srcBtnAddUp       = null;
		var srcBtnAddOver     = null;
		var srcBtnAddDown     = null;
		var srcBtnBackUp      = null;
		var srcBtnBackOver    = null;
		var srcBtnBackDown    = null;
		var srcBtnMinusUp     = null;
		var srcBtnMinusOver   = null;
		var srcBtnMinusDown   = null;
		var srcBtnPersentUp   = null;
		var srcBtnPersentOver = null;
		var srcBtnPersentDown = null;
		var srcBtnDivUp       = null;
		var srcBtnDivOver     = null;
		var srcBtnDivDown     = null;
		var srcBtnMultiUp     = null;
		var srcBtnMultiOver   = null;
		var srcBtnMultiDown   = null;
		var srcBtnSubUp       = null;
		var srcBtnSubOver     = null;
		var srcBtnSubDown     = null;
		var srcBtnDottUp      = null;
		var srcBtnDottOver    = null;
		var srcBtnDottDown    = null;
		var srcBtnEqualUp     = null;
		var srcBtnEqualOver   = null;
		var srcBtnEqualDown   = null;
		var srcBtn0Up         = null;
		var srcBtn0Over       = null;
		var srcBtn0Down       = null;
		var srcBtn1Up         = null;
		var srcBtn1Over       = null;
		var srcBtn1Down       = null;
		var srcBtn2Up         = null;
		var srcBtn2Over       = null;
		var srcBtn2Down       = null;
		var srcBtn3Up         = null;
		var srcBtn3Over       = null;
		var srcBtn3Down       = null;
		var srcBtn4Up         = null;
		var srcBtn4Over       = null;
		var srcBtn4Down       = null;
		var srcBtn5Up         = null;
		var srcBtn5Over       = null;
		var srcBtn5Down       = null;
		var srcBtn6Up         = null;
		var srcBtn6Over       = null;
		var srcBtn6Down       = null;
		var srcBtn7Up         = null;
		var srcBtn7Over       = null;
		var srcBtn7Down       = null;
		var srcBtn8Up         = null;
		var srcBtn8Over       = null;
		var srcBtn8Down       = null;
		var srcBtn9Up         = null;
		var srcBtn9Over       = null;
		var srcBtn9Down       = null;
		if (!aaoh.kaze.Type.isGoogle() && !aaoh.kaze.Type.isIE()) {
			srcBtnCopyUp    = 'images/calc' + type + '-copy_u.png';
			srcBtnPasteUp   = 'images/calc' + type + '-paste_u.png';
			srcBtnClearUp   = 'images/calc' + type + '-clear_u.png';
			srcBtnAddUp     = 'images/calc' + type + '-add_u.png';
			srcBtnBackUp    = 'images/calc' + type + '-back_u.png';
			srcBtnMinusUp   = 'images/calc' + type + '-num_u.png';
			srcBtnPersentUp = 'images/calc' + type + '-num_u.png';
			srcBtnDivUp     = 'images/calc' + type + '-num_u.png';
			srcBtnMultiUp   = 'images/calc' + type + '-num_u.png';
			srcBtnSubUp     = 'images/calc' + type + '-num_u.png';
			srcBtnDottUp    = 'images/calc' + type + '-num_u.png';
			srcBtnEqualUp   = 'images/calc' + type + '-num_u.png';
			srcBtn0Up       = 'images/calc' + type + '-num_u.png';
			srcBtn1Up       = 'images/calc' + type + '-num_u.png';
			srcBtn2Up       = 'images/calc' + type + '-num_u.png';
			srcBtn3Up       = 'images/calc' + type + '-num_u.png';
			srcBtn4Up       = 'images/calc' + type + '-num_u.png';
			srcBtn5Up       = 'images/calc' + type + '-num_u.png';
			srcBtn6Up       = 'images/calc' + type + '-num_u.png';
			srcBtn7Up       = 'images/calc' + type + '-num_u.png';
			srcBtn8Up       = 'images/calc' + type + '-num_u.png';
			srcBtn9Up       = 'images/calc' + type + '-num_u.png';

		} else {
			srcBtnCopyUp    = 'sub-images/calc' + type + '-copy_u_up.png';
			srcBtnPasteUp   = 'sub-images/calc' + type + '-paste_u_up.png';
			srcBtnClearUp   = 'sub-images/calc' + type + '-clear_u_up.png';
			srcBtnAddUp     = 'sub-images/calc' + type + '-add_u_up.png';
			srcBtnBackUp    = 'sub-images/calc' + type + '-back_u_up.png';
			srcBtnMinusUp   = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtnPersentUp = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtnDivUp     = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtnMultiUp   = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtnSubUp     = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtnDottUp    = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtnEqualUp   = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn0Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn1Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn2Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn3Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn4Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn5Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn6Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn7Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn8Up       = 'sub-images/calc' + type + '-num_u_up.png';
			srcBtn9Up       = 'sub-images/calc' + type + '-num_u_up.png';
		}
		srcBtnCopyOver    = 'sub-images/calc' + type + '-copy_u_over.png';
		srcBtnCopyDown    = 'sub-images/calc' + type + '-copy_u_down.png';
		srcBtnPasteOver   = 'sub-images/calc' + type + '-paste_u_over.png';
		srcBtnPasteDown   = 'sub-images/calc' + type + '-paste_u_down.png';
		srcBtnClearOver   = 'sub-images/calc' + type + '-clear_u_over.png';
		srcBtnClearDown   = 'sub-images/calc' + type + '-clear_u_down.png';
		srcBtnAddOver     = 'sub-images/calc' + type + '-add_u_over.png';
		srcBtnAddDown     = 'sub-images/calc' + type + '-add_u_down.png';
		srcBtnBackOver    = 'sub-images/calc' + type + '-back_u_over.png';
		srcBtnBackDown    = 'sub-images/calc' + type + '-back_u_down.png';
		srcBtnMinusOver   = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtnMinusDown   = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtnPersentOver = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtnPersentDown = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtnDivOver     = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtnDivDown     = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtnMultiOver   = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtnMultiDown   = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtnSubOver     = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtnSubDown     = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtnDottOver    = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtnDottDown    = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtnEqualOver   = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtnEqualDown   = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn0Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn0Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn1Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn1Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn2Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn2Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn3Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn3Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn4Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn4Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn5Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn5Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn6Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn6Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn7Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn7Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn8Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn8Down       = 'sub-images/calc' + type + '-num_u_down.png';
		srcBtn9Over       = 'sub-images/calc' + type + '-num_u_over.png';
		srcBtn9Down       = 'sub-images/calc' + type + '-num_u_down.png';

		aaoh.kaze.Element.setBackgroundImage(
			btnCopy, srcBtnCopyUp, srcBtnCopyOver, srcBtnCopyDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnPaste, srcBtnPasteUp, srcBtnPasteOver, srcBtnPasteDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnClear, srcBtnClearUp, srcBtnClearOver, srcBtnClearDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnAdd, srcBtnAddUp, srcBtnAddOver, srcBtnAddDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnBack, srcBtnBackUp, srcBtnBackOver, srcBtnBackDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnMinus, srcBtnMinusUp, srcBtnMinusOver, srcBtnMinusDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnPersent, srcBtnPersentUp, srcBtnPersentOver, srcBtnPersentDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnDiv, srcBtnDivUp, srcBtnDivOver, srcBtnDivDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnMulti, srcBtnMultiUp, srcBtnMultiOver, srcBtnMultiDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnSub, srcBtnSubUp, srcBtnSubOver, srcBtnSubDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnDott, srcBtnDottUp, srcBtnDottOver, srcBtnDottDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnEqual, srcBtnEqualUp, srcBtnEqualOver, srcBtnEqualDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn0, srcBtn0Up, srcBtn0Over, srcBtn0Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn1, srcBtn1Up, srcBtn1Over, srcBtn1Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn2, srcBtn2Up, srcBtn2Over, srcBtn2Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn3, srcBtn3Up, srcBtn3Over, srcBtn3Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn4, srcBtn4Up, srcBtn4Over, srcBtn4Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn5, srcBtn5Up, srcBtn5Over, srcBtn5Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn6, srcBtn6Up, srcBtn6Over, srcBtn6Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn7, srcBtn7Up, srcBtn7Over, srcBtn7Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn8, srcBtn8Up, srcBtn8Over, srcBtn8Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btn9, srcBtn9Up, srcBtn9Over, srcBtn9Down
		);

		// イメージの保存
		this.btnBgImgs_u['btnCopy'] = new Array(
			srcBtnCopyUp, srcBtnCopyOver, srcBtnCopyDown
		);
		this.btnBgImgs_u['btnPaste'] = new Array(
			srcBtnPasteUp, srcBtnPasteOver, srcBtnPasteDown
		);
		this.btnBgImgs_u['btnClear'] = new Array(
			srcBtnClearUp, srcBtnClearOver, srcBtnClearDown
		);
		this.btnBgImgs_u['btnAdd'] = new Array(
			srcBtnAddUp, srcBtnAddOver, srcBtnAddDown
		);
		this.btnBgImgs_u['btnBack'] = new Array(
			srcBtnBackUp, srcBtnBackOver, srcBtnBackDown
		);
		this.btnBgImgs_u['btnMinus'] = new Array(
			srcBtnMinusUp, srcBtnMinusOver, srcBtnMinusDown
		);
		this.btnBgImgs_u['btnPersent'] = new Array(
			srcBtnPersentUp, srcBtnPersentOver, srcBtnPersentDown
		);
		this.btnBgImgs_u['btnDiv'] = new Array(
			srcBtnDivUp, srcBtnDivOver, srcBtnDivDown
		);
		this.btnBgImgs_u['btnMulti'] = new Array(
			srcBtnMultiUp, srcBtnMultiOver, srcBtnMultiDown
		);
		this.btnBgImgs_u['btnSub'] = new Array(
			srcBtnSubUp, srcBtnSubOver, srcBtnSubDown
		);
		this.btnBgImgs_u['btnDott'] = new Array(
			srcBtnDottUp, srcBtnDottOver, srcBtnDottDown
		);
		this.btnBgImgs_u['btnEqual'] = new Array(
			srcBtnEqualUp, srcBtnEqualOver, srcBtnEqualDown
		);
		this.btnBgImgs_u['btn0'] = new Array(
			srcBtn0Up, srcBtn0Over, srcBtn0Down
		);
		this.btnBgImgs_u['btn1'] = new Array(
			srcBtn1Up, srcBtn1Over, srcBtn1Down
		);
		this.btnBgImgs_u['btn2'] = new Array(
			srcBtn2Up, srcBtn2Over, srcBtn2Down
		);
		this.btnBgImgs_u['btn3'] = new Array(
			srcBtn3Up, srcBtn3Over, srcBtn3Down
		);
		this.btnBgImgs_u['btn4'] = new Array(
			srcBtn4Up, srcBtn4Over, srcBtn4Down
		);
		this.btnBgImgs_u['btn5'] = new Array(
			srcBtn5Up, srcBtn5Over, srcBtn5Down
		);
		this.btnBgImgs_u['btn6'] = new Array(
			srcBtn6Up, srcBtn6Over, srcBtn6Down
		);
		this.btnBgImgs_u['btn7'] = new Array(
			srcBtn7Up, srcBtn7Over, srcBtn7Down
		);
		this.btnBgImgs_u['btn8'] = new Array(
			srcBtn8Up, srcBtn8Over, srcBtn8Down
		);
		this.btnBgImgs_u['btn9'] = new Array(
			srcBtn9Up, srcBtn9Over, srcBtn9Down
		);
	}

	/**
	 * イベントの設定。
	 */
	calc.Main.prototype.
	setEventListener = function() {
		this.setCalcEventListener();
		this.setOnDockEventListener();
		this.setUnDockEventListener();
	}

	/**
	 * イベントの設定。
	 */
	calc.Main.prototype.
	setCalcEventListener = function() {
		if (aaoh.kaze.Type.isYahoo()) {
			var index = aaoh.kaze.Gadget.$('index');
			if (index != null) {
				aaoh.kaze.Element.setOnKeyDown(index, function(event) {
					aaoh.sora.App.main.setImgInput(event);
				});
				aaoh.kaze.Element.setOnKeyUp(index, function(event) {
					aaoh.sora.App.main.doInput(event);
				});
			}

		} else {
			var txtCalc = aaoh.kaze.Gadget.$('txtCalc');
			if (txtCalc != null) {
				aaoh.kaze.Element.setOnKeyDown(txtCalc, function(event) {
					aaoh.sora.App.main.setImgInput(event);
				});
				aaoh.kaze.Element.setOnKeyUp(txtCalc, function(event) {
					aaoh.sora.App.main.doInput(event);
				});
			}

			var txtCalc_u = aaoh.kaze.Gadget.$('txtCalc_u');
			if (txtCalc_u != null) {
				aaoh.kaze.Element.setOnKeyDown(txtCalc_u, function(event) {
					aaoh.sora.App.main.setImgInput(event);
				});
				aaoh.kaze.Element.setOnKeyUp(txtCalc_u, function(event) {
					aaoh.sora.App.main.doInput(event);
				});
			}
		}
	}

	/**
	 * イベントの設定。
	 */
	calc.Main.prototype.
	setOnDockEventListener = function() {
		var btnCopy = aaoh.kaze.Gadget.$('btnCopy');
		if (btnCopy != null) {
			aaoh.kaze.Element.setOnClick(btnCopy, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doCopy();
			});
		}

		var btnPaste = aaoh.kaze.Gadget.$('btnPaste');
		if (btnPaste != null) {
			aaoh.kaze.Element.setOnClick(btnPaste, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doPaste();
			});
		}

		var btnClear = aaoh.kaze.Gadget.$('btnClear');
		if (btnClear != null) {
			aaoh.kaze.Element.setOnClick(btnClear, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doClear();
			});
		}

		var btnAdd = aaoh.kaze.Gadget.$('btnAdd');
		if (btnAdd != null) {
			aaoh.kaze.Element.setOnClick(btnAdd, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('+');
			});
		}

		var btnBack = aaoh.kaze.Gadget.$('btnBack');
		if (btnBack != null) {
			aaoh.kaze.Element.setOnClick(btnBack, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doBack();
			});
		}

		var btnMinus = aaoh.kaze.Gadget.$('btnMinus');
		if (btnMinus != null) {
			aaoh.kaze.Element.setOnClick(btnMinus, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doMinus();
			});
		}

		var btnPersent = aaoh.kaze.Gadget.$('btnPersent');
		if (btnPersent != null) {
			aaoh.kaze.Element.setOnClick(btnPersent, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doPersent();
			});
		}

		var btnDiv = aaoh.kaze.Gadget.$('btnDiv');
		if (btnDiv != null) {
			aaoh.kaze.Element.setOnClick(btnDiv, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('/');
			});
		}

		var btnMulti = aaoh.kaze.Gadget.$('btnMulti');
		if (btnMulti != null) {
			aaoh.kaze.Element.setOnClick(btnMulti, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('*');
			});
		}

		var btnSub = aaoh.kaze.Gadget.$('btnSub');
		if (btnSub != null) {
			aaoh.kaze.Element.setOnClick(btnSub, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('-');
			});
		}

		var btnDott = aaoh.kaze.Gadget.$('btnDott');
		if (btnDott != null) {
			aaoh.kaze.Element.setOnClick(btnDott, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('.');
			});
		}

		var btnEqual = aaoh.kaze.Gadget.$('btnEqual');
		if (btnEqual != null) {
			aaoh.kaze.Element.setOnClick(btnEqual, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doCalc();
			});
		}

		var btn0 = aaoh.kaze.Gadget.$('btn0');
		if (btn0 != null) {
			aaoh.kaze.Element.setOnClick(btn0, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('0');
			});
		}

		var btn1 = aaoh.kaze.Gadget.$('btn1');
		if (btn1 != null) {
			aaoh.kaze.Element.setOnClick(btn1, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('1');
			});
		}

		var btn2 = aaoh.kaze.Gadget.$('btn2');
		if (btn2 != null) {
			aaoh.kaze.Element.setOnClick(btn2, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('2');
			});
		}

		var btn3 = aaoh.kaze.Gadget.$('btn3');
		if (btn3 != null) {
			aaoh.kaze.Element.setOnClick(btn3, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('3');
			});
		}

		var btn4 = aaoh.kaze.Gadget.$('btn4');
		if (btn4 != null) {
			aaoh.kaze.Element.setOnClick(btn4, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('4');
			});
		}

		var btn5 = aaoh.kaze.Gadget.$('btn5');
		if (btn5 != null) {
			aaoh.kaze.Element.setOnClick(btn5, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('5');
			});
		}

		var btn6 = aaoh.kaze.Gadget.$('btn6');
		if (btn6 != null) {
			aaoh.kaze.Element.setOnClick(btn6, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('6');
			});
		}

		var btn7 = aaoh.kaze.Gadget.$('btn7');
		if (btn7 != null) {
			aaoh.kaze.Element.setOnClick(btn7, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('7');
			});
		}

		var btn8 = aaoh.kaze.Gadget.$('btn8');
		if (btn8 != null) {
			aaoh.kaze.Element.setOnClick(btn8, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('8');
			});
		}

		var btn9 = aaoh.kaze.Gadget.$('btn9');
		if (btn9 != null) {
			aaoh.kaze.Element.setOnClick(btn9, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('9');
			});
		}
	}

	/**
	 * イベントの設定。
	 */
	calc.Main.prototype.
	setUnDockEventListener = function() {
		var btnCopy = aaoh.kaze.Gadget.$('btnCopy_u');
		if (btnCopy != null) {
			aaoh.kaze.Element.setOnClick(btnCopy, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doCopy();
			});
		}

		var btnPaste = aaoh.kaze.Gadget.$('btnPaste_u');
		if (btnPaste != null) {
			aaoh.kaze.Element.setOnClick(btnPaste, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doPaste();
			});
		}

		var btnClear = aaoh.kaze.Gadget.$('btnClear_u');
		if (btnClear != null) {
			aaoh.kaze.Element.setOnClick(btnClear, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doClear();
			});
		}

		var btnAdd = aaoh.kaze.Gadget.$('btnAdd_u');
		if (btnAdd != null) {
			aaoh.kaze.Element.setOnClick(btnAdd, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('+');
			});
		}

		var btnBack = aaoh.kaze.Gadget.$('btnBack_u');
		if (btnBack != null) {
			aaoh.kaze.Element.setOnClick(btnBack, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doBack();
			});
		}

		var btnMinus = aaoh.kaze.Gadget.$('btnMinus_u');
		if (btnMinus != null) {
			aaoh.kaze.Element.setOnClick(btnMinus, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doMinus();
			});
		}

		var btnPersent = aaoh.kaze.Gadget.$('btnPersent_u');
		if (btnPersent != null) {
			aaoh.kaze.Element.setOnClick(btnPersent, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doPersent();
			});
		}

		var btnDiv = aaoh.kaze.Gadget.$('btnDiv_u');
		if (btnDiv != null) {
			aaoh.kaze.Element.setOnClick(btnDiv, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('/');
			});
		}

		var btnMulti = aaoh.kaze.Gadget.$('btnMulti_u');
		if (btnMulti != null) {
			aaoh.kaze.Element.setOnClick(btnMulti, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('*');
			});
		}

		var btnSub = aaoh.kaze.Gadget.$('btnSub_u');
		if (btnSub != null) {
			aaoh.kaze.Element.setOnClick(btnSub, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addSign('-');
			});
		}

		var btnDott = aaoh.kaze.Gadget.$('btnDott_u');
		if (btnDott != null) {
			aaoh.kaze.Element.setOnClick(btnDott, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('.');
			});
		}

		var btnEqual = aaoh.kaze.Gadget.$('btnEqual_u');
		if (btnEqual != null) {
			aaoh.kaze.Element.setOnClick(btnEqual, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.doCalc();
			});
		}

		var btn0 = aaoh.kaze.Gadget.$('btn0_u');
		if (btn0 != null) {
			aaoh.kaze.Element.setOnClick(btn0, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('0');
			});
		}

		var btn1 = aaoh.kaze.Gadget.$('btn1_u');
		if (btn1 != null) {
			aaoh.kaze.Element.setOnClick(btn1, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('1');
			});
		}

		var btn2 = aaoh.kaze.Gadget.$('btn2_u');
		if (btn2 != null) {
			aaoh.kaze.Element.setOnClick(btn2, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('2');
			});
		}

		var btn3 = aaoh.kaze.Gadget.$('btn3_u');
		if (btn3 != null) {
			aaoh.kaze.Element.setOnClick(btn3, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('3');
			});
		}

		var btn4 = aaoh.kaze.Gadget.$('btn4_u');
		if (btn4 != null) {
			aaoh.kaze.Element.setOnClick(btn4, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('4');
			});
		}

		var btn5 = aaoh.kaze.Gadget.$('btn5_u');
		if (btn5 != null) {
			aaoh.kaze.Element.setOnClick(btn5, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('5');
			});
		}

		var btn6 = aaoh.kaze.Gadget.$('btn6_u');
		if (btn6 != null) {
			aaoh.kaze.Element.setOnClick(btn6, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('6');
			});
		}

		var btn7 = aaoh.kaze.Gadget.$('btn7_u');
		if (btn7 != null) {
			aaoh.kaze.Element.setOnClick(btn7, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('7');
			});
		}

		var btn8 = aaoh.kaze.Gadget.$('btn8_u');
		if (btn8 != null) {
			aaoh.kaze.Element.setOnClick(btn8, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('8');
			});
		}

		var btn9 = aaoh.kaze.Gadget.$('btn9_u');
		if (btn9 != null) {
			aaoh.kaze.Element.setOnClick(btn9, function() {
				aaoh.sora.App.main.setFocus();
				aaoh.sora.App.main.addNumber('9');
			});
		}
	}

	/**
	 * 初期化処理。
	 */
	calc.Main.prototype.
	init = function() {
		this.setEventListener();
	}
})();
